=== modified file 'mysys/array.cc'
--- mysys/array.cc	2009-05-15 15:50:12 +0000
+++ mysys/array.cc	2009-06-24 23:48:15 +0000
@@ -18,6 +18,10 @@
 #include "mysys/mysys_priv.h"
 #include <mystrings/m_string.h>
 
+#include <algorithm>
+
+using namespace std;
+
 /*
   Initiate dynamic array
 
@@ -46,7 +50,7 @@
 {
   if (!alloc_increment)
   {
-    alloc_increment=cmax((8192-MALLOC_OVERHEAD)/element_size,16);
+    alloc_increment=max((8192-MALLOC_OVERHEAD)/element_size,16U);
     if (init_alloc > 8 && alloc_increment > init_alloc * 2)
       alloc_increment=init_alloc*2;
   }

=== modified file 'mysys/default.cc'
--- mysys/default.cc	2009-04-17 21:01:47 +0000
+++ mysys/default.cc	2009-06-24 23:48:15 +0000
@@ -40,6 +40,9 @@
 #include <drizzled/configmake.h>
 
 #include <stdio.h>
+#include <algorithm>
+
+using namespace std;
 
 const char *my_defaults_file=0;
 const char *my_defaults_group_suffix=0;
@@ -724,8 +727,8 @@
       for ( ; my_isspace(&my_charset_utf8_general_ci,end[-1]) ; end--) ;
       end[0]=0;
 
-      strncpy(curr_gr, ptr, cmin((size_t) (end-ptr)+1, sizeof(curr_gr)-1));
-      curr_gr[cmin((size_t)(end-ptr)+1, sizeof(curr_gr)-1)] = '\0';
+      strncpy(curr_gr, ptr, min((size_t) (end-ptr)+1, sizeof(curr_gr)-1));
+      curr_gr[min((size_t)(end-ptr)+1, sizeof(curr_gr)-1)] = '\0';
 
       /* signal that a new group is found */
       opt_handler(handler_ctx, curr_gr, NULL);

=== modified file 'mysys/default_modify.cc'
--- mysys/default_modify.cc	2009-04-17 21:01:47 +0000
+++ mysys/default_modify.cc	2009-06-24 23:48:15 +0000
@@ -18,6 +18,9 @@
 #include <mysys/my_dir.h>
 
 #include <stdio.h>
+#include <algorithm>
+
+using namespace std;
 
 #define BUFF_SIZE 1024
 #define RESERVE 1024                   /* Extend buffer with this extent */
@@ -93,13 +96,13 @@
                      NEWLINE_LEN +              /* Space for newline */
                      RESERVE);                  /* Some additional space */
 
-  buffer_size= (size_t)cmax((uint64_t)file_stat.st_size + 1, (uint64_t)SIZE_MAX);
+  buffer_size= (size_t)max((uint64_t)file_stat.st_size + 1, (uint64_t)SIZE_MAX);
 
   /*
     Reserve space to read the contents of the file and some more
     for the option we want to add.
   */
-  if (!(file_buffer= (char*) malloc(cmax(buffer_size + reserve_extended,
+  if (!(file_buffer= (char*) malloc(max(buffer_size + reserve_extended,
                                          SIZE_MAX))))
     goto malloc_err;
 

=== modified file 'mysys/mf_dirname.cc'
--- mysys/mf_dirname.cc	2009-06-09 21:56:05 +0000
+++ mysys/mf_dirname.cc	2009-06-24 23:48:15 +0000
@@ -16,6 +16,11 @@
 #include "mysys/mysys_priv.h"
 #include <mystrings/m_string.h>
 
+#include <algorithm>
+
+using namespace std;
+
+
 	/* Functions definied in this file */
 
 size_t dirname_length(const char *name)
@@ -69,7 +74,7 @@
   SYNPOSIS
     convert_dirname()
     to				Store result here. Must be at least of size
-    				cmin(FN_REFLEN, strlen(from) + 1) to make room
+    				min(FN_REFLEN, strlen(from) + 1) to make room
     				for adding FN_LIBCHAR at the end.
     from			Original filename. May be == to
     from_end			Pointer at end of filename (normally end \0)
@@ -122,7 +127,7 @@
   }
 #else
   /* This is ok even if to == from, becasue we need to cut the string */
-  size_t len= cmin(strlen(from),(size_t)(from_end-from));
+  size_t len= min(strlen(from),(size_t)(from_end-from));
   assert(memmove(to, from, len));
   to+= len;
   to[0]= '\0';

=== modified file 'mysys/mf_format.cc'
--- mysys/mf_format.cc	2009-04-17 21:01:47 +0000
+++ mysys/mf_format.cc	2009-06-24 23:48:15 +0000
@@ -16,6 +16,10 @@
 #include "mysys/mysys_priv.h"
 #include <mystrings/m_string.h>
 
+#include <algorithm>
+
+using namespace std;
+
 /*
   Formats a filename with possible replace of directory of extension
   Function can handle the case where 'to' == 'name'
@@ -76,7 +80,7 @@
     size_t tmp_length;
     if (flag & MY_SAFE_PATH)
       return NULL;
-    tmp_length= cmin(strlength(startpos), FN_REFLEN-1);
+    tmp_length= min(strlength(startpos), (size_t)(FN_REFLEN-1));
     strncpy(to,startpos,tmp_length);
     to[tmp_length]= '\0';
   }

=== modified file 'mysys/mf_iocache.cc'
--- mysys/mf_iocache.cc	2009-05-21 00:57:05 +0000
+++ mysys/mf_iocache.cc	2009-06-24 23:48:15 +0000
@@ -58,6 +58,9 @@
 #include <errno.h>
 #include <drizzled/util/test.h>
 #include <stdlib.h>
+#include <algorithm>
+
+using namespace std;
 
 #define lock_append_buffer(info) \
  pthread_mutex_lock(&(info)->append_buffer_lock)
@@ -1017,7 +1020,7 @@
   */
   while (write_length)
   {
-    size_t copy_length= cmin(write_length, write_cache->buffer_length);
+    size_t copy_length= min(write_length, write_cache->buffer_length);
     int  rc;
 
     rc= lock_io_cache(write_cache, write_cache->pos_in_file);
@@ -1175,7 +1178,7 @@
       TODO: figure out if the assert below is needed or correct.
     */
     assert(pos_in_file == info->end_of_file);
-    copy_len=cmin(Count, len_in_buff);
+    copy_len=min(Count, len_in_buff);
     memcpy(Buffer, info->append_read_pos, copy_len);
     info->append_read_pos += copy_len;
     Count -= copy_len;
@@ -1277,7 +1280,7 @@
       }
     }
 	/* Copy found bytes to buffer */
-    length=cmin(Count,read_length);
+    length=min(Count,read_length);
     memcpy(Buffer,info->read_pos,(size_t) length);
     Buffer+=length;
     Count-=length;
@@ -1310,7 +1313,7 @@
       if ((read_length=my_read(info->file,info->request_pos,
 			       read_length, info->myflags)) == (size_t) -1)
         return info->error= -1;
-      use_length=cmin(Count,read_length);
+      use_length=min(Count,read_length);
       memcpy(Buffer,info->request_pos,(size_t) use_length);
       info->read_pos=info->request_pos+Count;
       info->read_end=info->request_pos+read_length;

=== modified file 'mysys/my_alloc.cc'
--- mysys/my_alloc.cc	2009-04-17 21:01:47 +0000
+++ mysys/my_alloc.cc	2009-06-24 23:48:15 +0000
@@ -18,6 +18,9 @@
 #include "mysys/mysys_priv.h"
 #include <mystrings/m_string.h>
 
+#include <algorithm>
+
+using namespace std;
 
 /*
   Initialize memory root
@@ -154,7 +157,7 @@
   {						/* Time to alloc new block */
     block_size= mem_root->block_size * (mem_root->block_num >> 2);
     get_size= length+ALIGN_SIZE(sizeof(USED_MEM));
-    get_size= cmax(get_size, block_size);
+    get_size= max(get_size, block_size);
 
     if (!(next = (USED_MEM*) malloc(get_size)))
     {

=== modified file 'mysys/my_bitmap.cc'
--- mysys/my_bitmap.cc	2009-05-23 00:05:52 +0000
+++ mysys/my_bitmap.cc	2009-06-24 23:48:15 +0000
@@ -34,6 +34,10 @@
 #include <mystrings/m_string.h>
 #include <mysys/my_bit.h>
 
+#include <algorithm>
+
+using namespace std;
+
 void create_last_word_mask(MY_BITMAP *map)
 {
   /* Get the number of used bits (1..8) in the last byte */
@@ -282,7 +286,7 @@
 
   assert(map->bitmap && map2->bitmap);
 
-  end= to+cmin(len,len2);
+  end= to+min(len,len2);
   *map2->last_word_ptr&= ~map2->last_word_mask; /*Clear last bits in map2*/
   while (to < end)
     *to++ &= *from++;

=== modified file 'mysys/my_getopt.cc'
--- mysys/my_getopt.cc	2009-04-17 21:01:47 +0000
+++ mysys/my_getopt.cc	2009-06-24 23:48:15 +0000
@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <iostream>
+#include <algorithm>
 
 using namespace std;
 
@@ -971,7 +972,7 @@
   }
   if (optp->max_value && num > (double) optp->max_value)
     num= (double) optp->max_value;
-  return cmax(num, (double) optp->min_value);
+  return max(num, (double) optp->min_value);
 }
 
 /*

=== modified file 'mysys/my_time.cc'
--- mysys/my_time.cc	2009-05-21 17:05:14 +0000
+++ mysys/my_time.cc	2009-06-24 23:48:15 +0000
@@ -22,6 +22,10 @@
 #include <drizzled/util/test.h>
 
 #include <stdio.h>
+#include <algorithm>
+
+using namespace std;
+
 /* Windows version of localtime_r() is declared in my_ptrhead.h */
 
 uint64_t log_10_int[20]=
@@ -250,7 +254,7 @@
     2003-03-03 20:00:20 AM
     20:00:20.000000 AM 03-03-2000
   */
-  i= cmax((uint32_t) format_position[0], (uint32_t) format_position[1]);
+  i= max((uint32_t) format_position[0], (uint32_t) format_position[1]);
   set_if_bigger(i, (uint32_t) format_position[2]);
   allow_space= ((1 << i) | (1 << format_position[6]));
   allow_space&= (1 | 2 | 4 | 8);

